.. Pyansys links

.. _dev_guide_contributing: https://dev.docs.pyansys.com/how-to/contributing.html
.. _dev_guide_coding_style: https://dev.docs.pyansys.com/coding-style/index.html
.. _dev_guide_multi_version: https://dev.docs.pyansys.com/how-to/documenting.html#enable-multi-version-documentation


.. dependency links

.. _Sphinx: https://www.sphinx-doc.org/en/master/
.. _Sphinx_PyPI: https://pypi.org/project/Sphinx/
.. _PyData_PyPI: https://pypi.org/project/pydata-sphinx-theme/
.. _Jinja2_PyPI: https://pypi.org/project/Jinja2/
.. _pip: https://pypi.org/project/pip/
.. _Tox: https://tox.wiki/en/stable/

.. dependency docs links
.. _sphinx_design_examples: https://github.com/executablebooks/sphinx-design/tree/furo-theme/docs/snippets/rst
.. _sphinx_design_docs: https://sphinx-design.readthedocs.io/en/latest/index.html
.. _pydata_examples: https://pydata-sphinx-theme.readthedocs.io/en/stable/examples/kitchen-sink/index.html
.. _pydata_logo: https://pydata-sphinx-theme.readthedocs.io/en/stable/user_guide/branding.html#different-logos-for-light-and-dark-mode


.. ansys_sphinx_theme links

.. _static_files: https://github.com/ansys/ansys-sphinx-theme/blob/main/src/ansys_sphinx_theme/theme/ansys_sphinx_theme/static/logos/
.. _Ansys Sphinx theme issues: https://github.com/ansys/ansys-sphinx-theme/issues/


.. other links
.. _git: https://git-scm.com/
.. _configure SSH: https://docs.github.com/en/authentication/connecting-to-github-with-ssh